@@ -60,6 +60,9 @@ PlaylistItem::~PlaylistItem()
             playlist()->setPlaying(0);
     }
 
+    playlist()->updateDeletedItem(this);
+    emit playlist()->signalAboutToRemove(this);
+
     if(m_watched)
         Pointer::clear(this);
 }
@@ -84,11 +87,11 @@ FileHandle PlaylistItem::file() const
     return d->fileHandle;
 }
 
+K_GLOBAL_STATIC_WITH_ARGS(QPixmap, globalGenericImage, (SmallIcon("image-x-generic")))
+K_GLOBAL_STATIC_WITH_ARGS(QPixmap, globalPlayingImage, (UserIcon("playing")))
+
 const QPixmap *PlaylistItem::pixmap(int column) const
 {
-    static QPixmap image(SmallIcon("image-x-generic"));
-    static QPixmap playing(UserIcon("playing"));
-
     int offset = playlist()->columnOffset();
 
     // Don't use hasCover here because that may dig into the track itself.
@@ -98,12 +101,14 @@ const QPixmap *PlaylistItem::pixmap(int column) const
     if((column - offset) == CoverColumn &&
         d->fileHandle.coverInfo()->coverId() != CoverManager::NoMatch)
     {
-        return &image;
+        return globalGenericImage;
     }
 
     if(column == playlist()->leftColumn() &&
-       m_playingItems.contains(const_cast<PlaylistItem *>(this)))
-        return &playing;
+        m_playingItems.contains(const_cast<PlaylistItem *>(this)))
+    {
+        return globalPlayingImage;
+    }
 
     return K3ListViewItem::pixmap(column);
 }
@@ -336,7 +341,7 @@ int PlaylistItem::compare(const PlaylistItem *firstItem, const PlaylistItem *sec
 {
     int offset = playlist()->columnOffset();
 
-    if(column < 0 || column > lastColumn() + offset)
+    if(column < 0 || column > lastColumn() + offset || !firstItem->d || !secondItem->d)
         return 0;
 
     if(column < offset) {
@@ -379,8 +384,8 @@ int PlaylistItem::compare(const PlaylistItem *firstItem, const PlaylistItem *sec
             return 1;
         break;
     default:
-        return strcoll(firstItem->d->local8Bit[column - offset],
-                       secondItem->d->local8Bit[column - offset]);
+        return QString::localeAwareCompare(firstItem->d->metadata[column - offset],
+                                           secondItem->d->metadata[column - offset]);
     }
 }
 
